@@ -14,14 +14,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from neutron.plugins.ml2.drivers.openvswitch.agent import vlanmanager
 from neutron_lib import constants as n_consts
+from neutron_lib.plugins.ml2 import ovs_constants as ovs_consts
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants \
-    as ovs_consts
-from neutron.plugins.ml2.drivers.openvswitch.agent import vlanmanager
-
 from networking_sfc.services.sfc.agent.extensions import sfc
 from networking_sfc.services.sfc.common import ovs_ext_lib
 from networking_sfc.services.sfc.drivers.ovs import constants
@@ -578,9 +576,9 @@ class SfcOVSAgentDriver(sfc.SfcAgentDriver):
 
     def _build_push_nsh(self, nsp, nsi):
         return (
-            "encap(hdr=nsh,prop(class=nsh,type=md_type,val=1)),"
+            "encap(nsh,prop(class=nsh,type=md_type,val=1)),"
             "set_field:%s->nsh_spi,set_field:%s->nsh_si,"
-            "encap(hdr=ethernet)," %
+            "encap(ethernet)," %
             (hex(nsp), hex(nsi)))
 
     def _build_ingress_common_match_field(self, vif_port, vlan):
@@ -615,9 +613,9 @@ class SfcOVSAgentDriver(sfc.SfcAgentDriver):
     def _build_proxy_sfc_nsh(self, flowrule, vif_port, vlan):
         match_field = self._build_ingress_match_field_sfc_nsh(
             flowrule, vif_port, vlan)
-        actions = ("strip_vlan,move:NXM_OF_ETH_DST->OXM_OF_PKT_REG[0..47],"
+        actions = ("strip_vlan,move:NXM_OF_ETH_DST->OXM_OF_PKT_REG0[0..47],"
                    "decap(),decap(),"
-                   "move:OXM_OF_PKT_REG[0..47]->NXM_OF_ETH_DST,output:%s"
+                   "move:OXM_OF_PKT_REG0[0..47]->NXM_OF_ETH_DST,output:%s"
                    "" % vif_port.ofport)
         match_field['actions'] = actions
         return match_field
@@ -656,7 +654,7 @@ class SfcOVSAgentDriver(sfc.SfcAgentDriver):
         group_content = self.br_int.dump_group_for_id(group_id)
         buckets = ','.join(buckets)
         if flowrule['fwd_path']:
-            if group_content.find('group_id=%d' % group_id) == -1:
+            if group_content.find('group_id=%d,' % group_id) == -1:
                 self.br_int.add_group(group_id=group_id,
                                       type='select',
                                       buckets=buckets)
@@ -667,7 +665,7 @@ class SfcOVSAgentDriver(sfc.SfcAgentDriver):
         else:
             # set different id for rev_group
             rev_group_id = group_id + REVERSE_GROUP_NUMBER_OFFSET
-            if group_content.find('group_id=%d' % (rev_group_id)) == -1:
+            if group_content.find('group_id=%d,' % (rev_group_id)) == -1:
                 self.br_int.add_group(group_id=rev_group_id,
                                       type='select',
                                       buckets=buckets)
