@@ -13,9 +13,8 @@
 #    under the License.
 
 from neutron.agent.common import ovs_lib
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants \
-    as ovs_consts
 from neutron_lib import exceptions
+from neutron_lib.plugins.ml2 import ovs_constants as ovs_consts
 from oslo_log import log as logging
 
 from networking_sfc._i18n import _
